==> openapi-rapi-client-0.0.17-sources.jar: com/xforceplus/ultraman/app/openapirapi/controller/AsyncTaskFeignApi.java <==
package com.xforceplus.ultraman.app.openapirapi.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-11-02
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.openapirapi.entity.AsyncTask;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "openapi-rapi")
public interface AsyncTaskFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/asyncTask/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param asyncTask ${table.comment}
   * @return R
   */
  @PostMapping("/asyncTask/add")
  public R save(@RequestBody AsyncTask asyncTask);

  /**
   * 修改${table.comment}
   * @param asyncTask ${table.comment}
   * @return R
   */
  @PostMapping("/asyncTask/update")
  public R updateById(@RequestBody AsyncTask asyncTask);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/asyncTask/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> openapi-rapi-client-0.0.45-sources.jar: com/xforceplus/ultraman/app/openapirapi/controller/AsyncTaskFeignApi.java <==
package com.xforceplus.ultraman.app.openapirapi.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-11-23
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.openapirapi.entity.AsyncTask;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "openapi-rapi")
public interface AsyncTaskFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/asyncTask/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param asyncTask ${table.comment}
   * @return R
   */
  @PostMapping("/asyncTask/add")
  public R save(@RequestBody AsyncTask asyncTask);

  /**
   * 修改${table.comment}
   * @param asyncTask ${table.comment}
   * @return R
   */
  @PostMapping("/asyncTask/update")
  public R updateById(@RequestBody AsyncTask asyncTask);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/asyncTask/del/{id}" )
  public R removeById(@PathVariable Long id);

}
